load_from_xlsx_bytes

Function load_from_xlsx_bytes 

pub fn load_from_xlsx_bytes(
    bytes: &[u8],
    name: &str,
    locale: &str,
    tz: &str,
) -> Result<Workbook, XlsxError>
Loads a Workbook from the bytes of an xlsx file. This is useful, for instance, when bytes are transferred over the network